@@ -1,6 +1,6 @@
 
 import unittest
-from mox3.mox import MoxTestBase, IsA
+from mox import MoxTestBase, IsA
 
 from slimta.queue.proxy import ProxyQueue
 from slimta.smtp.reply import Reply
