@@ -1,7 +1,7 @@
 
 import unittest
 
-from mox3.mox import MoxTestBase, IsA
+from mox import MoxTestBase, IsA
 from gevent.lock import Semaphore
 
 from slimta.util.deque import BlockingDeque
