@@ -1,6 +1,6 @@
 import unittest
 
-from mox3.mox import MoxTestBase
+from mox import MoxTestBase
 from pycares.errno import ARES_ENOTFOUND
 
 from slimta.util.dns import DNSResolver, DNSError
